compile_with_registry

Function compile_with_registry 

pub fn compile_with_registry(
    source: &str,
    supplied: &BTreeMap<String, String>,
    registry: &NativeRegistry,
) -> Result<Program, Vec<Diagnostic>>
Compile with explicit pure host signatures available to the static checker. The machine must receive a registry with these same signatures.

Errors

Returns source-linked syntax, declaration, type, or trait diagnostics.