pub fn document(
snapshot: &Snapshot,
revision: u64,
) -> Result<UiDocument, PresentationError>Expand description
Projects current language controls without executing callbacks or opening host resources.
Errors
Returns a presentation error for invalid control bounds or excessive UI content.